
local alist all
foreach q of local alist {

use ${dd}\ed_episodes_cleaned.dta, clear

*Default "all" is looking at both ASO and non-ASO episodes
if "`q'"=="aso" keep if aso=="Y"
if "`q'"=="non_aso" keep if aso=="N"

*NY and control states
keep if state=="NY" | state=="NJ" | state=="PA" | state=="CT" | state=="VT" | state=="MA"
loc ctrlabel "NJ, PA, CT, VT, MA"

*Time period of interest	
keep if qgroup>8

label var oon_ind "Out-of-Network Rate"
label var fac_payment "Facility Payment"
label var fac_charge "Facility Charge"
label var phys_payment "Physician Payment"
label var phys_charge "Physician Charge"

gen treat_tr=0
replace treat_tr=1 if state=="NY"

*Labels
tab qgroup, gen(quarter_dum)

	loc vlist ""
		d oon_ind phys_payment, varlist
		foreach v in `r(varlist)' {
			loc vlist "`vlist' `v'"
		}
		
		foreach v of loc vlist {
			local l`v': variable label `v'
			if `"`l`v''"' == "" {
				local l`v' "`v'"
			}
		}

*Time and NY interaction
d quarter_dum*, varlist
foreach v in `r(varlist)' {
	loc temp = subinstr("`v'", "quarter_dum", "", .)
	gen inter_tr_`temp' = `v'*treat_tr
	}
	

drop quarter_dum1 inter_tr_1
	
	
eststo clear
foreach v of loc vlist {
	
	tempfile temp
	eststo: areg `v' quarter_dum* treat_tr inter_tr* pat_female i.pat_age i.pat_race charind, absorb(aha) vce(cluster aha)
	parmest, saving(`temp', replace)
	loc Nx=e(N)
	
	preserve
	use `temp', clear
	
	*Keeping coefficients, standard errors, and confidence bands
	keep parm stderr min95 max95 estimate
	
		cap drop temp*
		gen temp =  substr(parm, 1, 8)
		gen temp2 = subinstr(parm, "o.", "", .)
		replace temp2 = subinstr(temp2, "inter_", "", .)
		replace temp2 = substr(temp2, 1, 2)
			
			*Treatment and controls
			cap drop est_*
			gen est_cr = estimate if temp2 == "qu" 
			gen est_tr = estimate if temp2 == "tr" 
				
			gen est_cr_min=min95 if temp2 == "qu" 
			gen est_cr_max=max95 if temp2 == "qu" 
			gen est_tr_min=min95 if temp2 == "tr"
			gen est_tr_max=max95 if temp2 == "tr"
				
			drop temp*
			
			*Quarterly numbers
			gen temp = real(substr(parm, -2, 2))
			replace temp=real(substr(parm,-1,1)) if temp==.
			cap drop quarter
			gen quarter=temp
			drop temp
				
			collapse (sum) est_*, by(quarter)
			
			*Values of coefficients to graph over time
			replace est_tr = est_tr + est_cr
			replace est_tr_min= est_tr_min+est_cr
			replace est_tr_max=est_tr_max+est_cr
				
			summ est_tr		
			loc min = round(r(min), 1)
			loc max = round(r(max), 1)
				
			drop if missing(quarter)
				
			count
			loc N = r(N)+1
			set obs `N'
			replace quarter = 1 if missing(quarter)
			qui d est*, varlist
			foreach t in `r(varlist)' {
				replace `t' = 0 if missing(`t')
			}
				
			sort quarter
			loc regvar = proper("`l`v''")
				
			*Graphical display, treatment, controls, and confidence bands for each
			local samptype ""
			if "`q'"=="aso" local samptype "ASO episodes only"
			if "`q'"=="non_aso" local samptype "Non-ASO episodes only"
			if "`q'"=="all" local samptype "all episodes"
			
				tw line est_tr quarter, lw(medthick)  lc(`blue')  ///
				|| line est_cr quarter, lwidth(medthick) lc(gs11) ///
				|| line est_tr_min quarter, lw(thin)  lc(`blue') lpattern(shortdash) ///
				|| line est_tr_max quarter, lw(thin)  lc(`blue') lpattern(shortdash) ///
				|| line est_cr_min quarter, lwidth(thin) lc(gs11) lpattern(shortdash) ///
				|| line est_cr_max quarter, lwidth(thin) lc(gs11) lpattern(shortdash) ///	
				title("Effect of NY Reform on:") ///
				subtitle("`regvar' (`samptype')", size(medlarge)) ///
				xlabel(1 "2013 Q1" 5 "2014 Q1"  9 "2015 Q1" 12 "2015 Q4", angle(90)) ///
				xtitle("") ///
				xline(9.6, lcolor(green) lwidth(thin)) ///
				xmtick(1 2 3 4 5 6 7 8 9 10 11 12, tlength(2) tposition(outside)) ///
				xline(5.6, lcolor(red) lwidth(thin)) ///
				legend(order(1 "New York" 2 "`ctrlabel'" 3 "95% CI" 5 "95% CI")) 
				
				graph export ${o}\final_figures\nydiffndiff_`v'.png, width(1500) height(1000) as(png) replace
				
				restore
				
				}
				}
				
				
	
				
